package de.hhhammer.dchat.bot;

import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
import de.hhhammer.dchat.bot.openai.ChatGPTService;
import de.hhhammer.dchat.db.ServerDBService;
import de.hhhammer.dchat.db.UserDBService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.http.HttpClient;

public class App {
    private static final Logger logger = LoggerFactory.getLogger(App.class);

    public static void main(String[] args) {
        String discordApiKey = System.getenv("DISCORD_API_KEY");
        if (discordApiKey == null) {
            logger.error("Missing environment variables: DISCORD_API_KEY");
            System.exit(1);
        }
        String openaiApiKey = System.getenv("OPENAI_API_KEY");
        if (openaiApiKey == null) {
            logger.error("Missing environment variables: OPENAI_API_KEY");
            System.exit(1);
        }
        String postgresUser = System.getenv("POSTGRES_USER");
        String postgresPassword = System.getenv("POSTGRES_PASSWORD");
        String postgresUrl = System.getenv("POSTGRES_URL");
        if (postgresUser == null || postgresPassword == null || postgresUrl == null) {
            logger.error("Missing environment variables: POSTGRES_USER and/or POSTGRES_PASSWORD and/or POSTGRES_URL");
            System.exit(1);
        }

        var chatGPTService = new ChatGPTService(openaiApiKey, HttpClient.newHttpClient());

        var config = new HikariConfig();
        config.setJdbcUrl(postgresUrl);
        config.setUsername(postgresUser);
        config.setPassword(postgresPassword);

        try (var ds = new HikariDataSource(config)) {
            var serverDBService = new ServerDBService(ds);
            var userDBService = new UserDBService(ds);

            var discordBot = new DiscordBot(serverDBService, userDBService, chatGPTService, discordApiKey);
            discordBot.run();
        }
    }
}
