package de.hhhammer.dchat.bot.openai;

import de.hhhammer.dchat.bot.openai.models.ChatGPTRequest;

import java.util.ArrayList;
import java.util.List;

public class ChatGPTRequestBuilder {
    private final String smallContextModel = "gpt-3.5-turbo";
    private final String bigContextModel = "gpt-3.5-turbo-16k";

    public ChatGPTRequestBuilder() {
    }

    public ChatGPTRequest simpleRequest(String content, String systemMessage) {
        return new ChatGPTRequest(
                smallContextModel,
                List.of(new ChatGPTRequest.Message("system", systemMessage), new ChatGPTRequest.Message("user", content)),
                0.7f
        );
    }

    public ChatGPTRequest replyRequest(List<String> contextMessages, String message, String systemMessage) {
        List<ChatGPTRequest.Message> messages = new ArrayList<>();
        messages.add(new ChatGPTRequest.Message("system", systemMessage));
        var context = contextMessages.stream()
                .map(m -> new ChatGPTRequest.Message("assistant", m))
                .toList();
        messages.addAll(context);
        messages.add(new ChatGPTRequest.Message("user", message));
        return new ChatGPTRequest(
                smallContextModel,
                messages,
                0.7f
        );
    }

    public ChatGPTRequest contextRequest(List<PreviousInteraction> contextMessages, String message, String systemMessage) {
        List<ChatGPTRequest.Message> messages = new ArrayList<>();
        messages.add(new ChatGPTRequest.Message("system", systemMessage));
        var context = contextMessages.stream()
                .map(m -> List.of(
                        new ChatGPTRequest.Message("user", m.question),
                        new ChatGPTRequest.Message("assistant", m.answer)
                ))
                .flatMap(List::stream)
                .toList();
        messages.addAll(context);
        messages.add(new ChatGPTRequest.Message("user", message));
        return new ChatGPTRequest(
                bigContextModel,
                messages,
                0.7f
        );
    }

    public record PreviousInteraction(String question, String answer) {
    }
}
