package de.hhhammer.dchat.web;

import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
import de.hhhammer.dchat.db.ServerDBService;
import de.hhhammer.dchat.db.UserDBService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Hello world!
 */
public class App {
    private static final Logger logger = LoggerFactory.getLogger(App.class);

    public static void main(String[] args) {
        String postgresUser = System.getenv("POSTGRES_USER");
        String postgresPassword = System.getenv("POSTGRES_PASSWORD");
        String postgresUrl = System.getenv("POSTGRES_URL");
        if (postgresUser == null || postgresPassword == null || postgresUrl == null) {
            logger.error("Missing environment variables: POSTGRES_USER and/or POSTGRES_PASSWORD and/or POSTGRES_URL");
            System.exit(1);
        }

        String apiPortStr = System.getenv("API_PORT") != null ? System.getenv("API_PORT") : "8080";
        int apiPort = Integer.parseInt(apiPortStr);
        boolean debug = "true".equals(System.getenv("API_DEBUG"));

        var config = new HikariConfig();
        config.setJdbcUrl(postgresUrl);
        config.setUsername(postgresUser);
        config.setPassword(postgresPassword);

        try (var ds = new HikariDataSource(config)) {
            var serverDBService = new ServerDBService(ds);
            var userDBService = new UserDBService(ds);
            var appConfig = new AppConfig(apiPort, debug);

            var webApi = new WebAPI(serverDBService, userDBService, appConfig);
            webApi.run();
        }
    }
}
